<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Ime_programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Naslednji</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>View Log</source>
        <translation>Prikaži dnevnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="259"/>
        <location filename="../mainwindow.cpp" line="505"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Select ISO</source>
        <translation>Izberi ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Izberite ciljni USB nosilec&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Izberite ISO datoteko&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Advanced Options</source>
        <translation>Napredne možnosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Napravi datotečni sistem ext4, četudi že obstaja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Med posodabljanjem živega usb nosilca shrani originalni zagonski direktorij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Uporabi gpt razdelke, namesto msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>GPT partitioning</source>
        <translation>GPT razdeljevanje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Posodobi (posodobi le obstoječ živi-usb)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Ne nadomesti syslinux datotek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="361"/>
        <source>Keep syslinux files</source>
        <translation>Obdrži syslinux datoteke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignoriraj preverjanje odstranljivosti za USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Temporarily disable automounting</source>
        <translation>Začasno onemogoči samodejni priklop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Določi zastavico pmbr_boot (ne deluje preko UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Ne uporabljajte fuseiso za priklop iso datotek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Velikost ESP (uefi) razdelka:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Verbosity (less to more):</source>
        <translation>Podrobnosti (manj do več):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Make separate data partition (percent)</source>
        <translation>Ustvari ločen razdelek (odstotki)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Refresh drive list</source>
        <translation>Osveži seznam pogonov</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Show advanced options</source>
        <translation>Prikaži napredne možnosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="567"/>
        <source>Mode</source>
        <translation>Način</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="582"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation>Polna funkcionalnost - zapisljiv živi-USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Samo branje. Ne deluje s persistenco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="595"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation>Posnetek diska - samo branje za živi-usb (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Za distribucije, ki niso antiX/MX, uporabite način posnetek diska (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>Percent of USB-device to use:</source>
        <translation>Odstotek rabe USB naprave:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="702"/>
        <source>Label ext partition:</source>
        <translation>Oznaka ext razdelka:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Ne izvajajte ukazov, ki lahko vplivajo na usb napravo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Dry run (no change to system)</source>
        <translation>Suh zagon (brez sistemskih sprememb)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>kloniraj iz priklopljeni živi-usb ali iso datoteko.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Clone an existing live system</source>
        <translation>Kloniraj obstoječ živi sistem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Namestitev, ki se zaganja iz šifrirane particije, bo ob prvem zagonu zahtevala vnos varnostne fraze.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Encrypt</source>
        <translation>Šifriranje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="780"/>
        <source>Clone running live system</source>
        <translation>Kloniraj zagnan živi sistem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>Confirmation</source>
        <translation>Potrditev</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="76"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation>Ciljna naprava %1 je večja od %2 GB.
Ali želite nadaljevati?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="116"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <location filename="../mainwindow.cpp" line="452"/>
        <source>Failure</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Vir in cilj se nahajata na isti napravi. Prosimo, ponovite izbor.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="152"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the process is completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Success</source>
        <translation>Operacija je uspela</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>LiveUSB creation successful!</source>
        <translation>ŽiviUSB je bil uspešno ustvarjen!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>ŽiviUSB ni bil uspešno ustvarjen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Please select a USB device to write to</source>
        <translation>Izberite USB napravo, na katero naj se zapisuje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Ta dejanje bodo uničila vse podatke na 

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Do you wish to continue?</source>
        <translation>Ali želite nadaljevati?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program, ki ustvari živi-usb iz iso datoteke, drugega živega usb pogona, živega cd/dvd ploščka ali iz sistema, ki je zagnan v živo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>%1 License</source>
        <translation>%1 licenca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>%1 Help</source>
        <translation>%1 pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Izberite ISO datoteko, ki naj se zapiše na USB pogon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>ISO datoteke (*.iso);;Vse datoteke (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Select Source Directory</source>
        <translation>Izberite direktorij z virom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Nisem našel datoteke %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Hide advanced options</source>
        <translation>Skrij napredne možnosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Select Source</source>
        <translation>Izberi vir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <location filename="../mainwindow.cpp" line="524"/>
        <source>Select ISO file</source>
        <translation>Izberi ISO datoteko</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>clone</source>
        <translation>kloniraj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Could not find a log file at: </source>
        <translation>Nisem našel dnevnika v:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program, ki ustvari živi-usb iz iso datoteke, drugega živega usb pogona, živega cd/dvd ploščka ali iz sistema, ki je zagnan v živo.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>filename</source>
        <translation>ime datoteke</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Name of .iso file to open</source>
        <translation>Ime .iso datoteke za odpiranje</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>[filename]</source>
        <translation>[ime datoteke]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Prijevljeni ste kot korenski uporabnik. Izpišite se in se ponovno prijavite kot običajen uporabnik, če želite uporabljati ta program.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="103"/>
        <source>version:</source>
        <translation>različica:</translation>
    </message>
</context>
</TS>
